@@ -16,7 +16,7 @@ Usage::
     session_client: PersonalizeRuntimeClient = session.client("personalize-runtime")
     ```
 """
-from mypy_boto3_personalize_runtime.client import PersonalizeRuntimeClient
+from .client import PersonalizeRuntimeClient
 
 Client = PersonalizeRuntimeClient
 
